@@ -124,7 +124,7 @@ import org.jasypt.salt.SaltGenerator;
  * 
  */
 public final class StandardPBEBigDecimalEncryptor 
-        implements PBEBigDecimalEncryptor {
+        implements PBEBigDecimalCleanablePasswordEncryptor {
 
     
     // The StandardPBEByteEncryptor that will be internally used.
@@ -219,6 +219,39 @@ public final class StandardPBEBigDecimalEncryptor
         this.byteEncryptor.setPassword(password);
     }
     
+    
+    /**
+     * <p>
+     * Sets the password to be used, as a char[].
+     * </p>
+     * <p>
+     * This allows the password to be specified as a <i>cleanable</i>
+     * char[] instead of a String, in extreme security conscious environments
+     * in which no copy of the password as an immutable String should
+     * be kept in memory.
+     * </p>
+     * <p>
+     * <b>Important</b>: the array specified as a parameter WILL BE COPIED
+     * in order to be stored as encryptor configuration. The caller of
+     * this method will therefore be responsible for its cleaning (jasypt
+     * will only clean the internally stored copy).
+     * </p>
+     * <p>
+     * <b>There is no default value for password</b>, so not setting
+     * this parameter either from a 
+     * {@link org.jasypt.encryption.pbe.config.PBEConfig} object or from
+     * a call to <tt>setPassword</tt> will result in an
+     * EncryptionInitializationException being thrown during initialization.
+     * </p>
+     * 
+     * @since 1.8
+     * 
+     * @param password the password to be used.
+     */
+    public void setPasswordCharArray(char[] password) {
+        this.byteEncryptor.setPasswordCharArray(password);
+    }
+    
 
     /**
      * <p>
@@ -317,16 +350,22 @@ public final class StandardPBEBigDecimalEncryptor
     
     
     /*
-     * Clone this encryptor.
+     * Clone this encryptor 'size' times and initialize it.
+     * This encryptor will be at position 0 itself.
+     * Clones will NOT be initialized.
      */
-    StandardPBEBigDecimalEncryptor cloneEncryptor() {
+    synchronized StandardPBEBigDecimalEncryptor[] cloneAndInitializeEncryptor(final int size) {
         
-        // Check initialization
-        if (!isInitialized()) {
-            initialize();
+        final StandardPBEByteEncryptor[] byteEncryptorClones =
+            this.byteEncryptor.cloneAndInitializeEncryptor(size);
+        
+        final StandardPBEBigDecimalEncryptor[] clones = new StandardPBEBigDecimalEncryptor[size];
+        
+        for (int i = 0; i < size; i++) {
+            clones[i] = new StandardPBEBigDecimalEncryptor(byteEncryptorClones[i]);
         }
         
-        return new StandardPBEBigDecimalEncryptor(this.byteEncryptor.cloneEncryptor());
+        return clones;
         
     }
     
